﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web.UI.WebControls;
using System.ComponentModel;
using System.Web.UI;
using System.Drawing;

namespace CustControl
{

    public enum CustImageType
    {
        Add,
        Edit,
        View,
        Delete
    }
    //指定组件的默认属性。
    [DefaultProperty("ImageType")]
    //指定当从 Microsoft Visual Studio 等工具中的工具箱拖动自定义控件时为它生成的默认标记
    [ToolboxData("<{0}:CustImageButton runat=server></{0}:CustImageButton>")]
    public class CustImageButton : ImageButton
    {
        
        //指定成员是否通常用于绑定。无法继承此类
        [Bindable(true)]
        //指定当属性或事件显示在一个设置为“按分类顺序”模式的 
        //System.Windows.Forms.PropertyGrid 控件中时，用于给属性或事件分组的类别的名称。
        [Category("Appearance")]
        //指定属性的默认值
        [DefaultValue(CustImageType.Add)]
        //指定属性是否应本地化
        [Localizable(true)]
        public CustImageType ImageType
        {
            get
            {
                return ViewState["ImageType"] == null ? CustImageType.Add : (CustImageType)ViewState["ImageType"];
            }
            set
            {
                ViewState["ImageType"] = value;
            }

        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="writer"></param>
        protected override void Render(HtmlTextWriter writer)
        {
            switch (ImageType)
            {
                case CustImageType.Add:
                    //Page.ClientScript.GetWebResourceUrl()获取对程序集内资源的 URL 引用
                    this.ImageUrl = this.Page.ClientScript.GetWebResourceUrl(this.GetType(), "CustControl.Images.Add.png");
                    break;
                case CustImageType.Edit:
                    this.ImageUrl = this.Page.ClientScript.GetWebResourceUrl(this.GetType(),"CustControl.Images.Edit.png");
                    break;
                case CustImageType.Delete:
                    this.ImageUrl = this.Page.ClientScript.GetWebResourceUrl(this.GetType(),"CustControl.Images.delete.png");
                    break;
                case CustImageType.View:
                    this.ImageUrl = this.Page.ClientScript.GetWebResourceUrl(this.GetType(),"CustControl.Images.View.png");
                    break;
            }
            base.Render(writer);
        }
    }
}
